LoReAll

Struct LoReAll 

pub struct LoReAll<'a> { /* private fields */ }

Implementations

Source

impl<'a> LoReAll<'a>

pub const fn new(value: &'a mut LocalResourceStorage) -> LoReAll<'a>

Methods from Deref<Target = LocalResourceStorage>

pub fn insert<R>(&mut self, resource: R)
where R: LocalResource,

Inserts a new resource into the storage.

If a resource of the same type already exists, it will be replaced.

pub fn fetch<R>(&self) -> &R
where R: LocalResource,

Retrieves a reference to a resource of type R.

Panics

Panics if the resource does not exist.

pub fn fetch_mut<R>(&mut self) -> &mut R
where R: LocalResource,

Retrieves a mutable reference to a resource of type R.

Panics

Panics if the resource does not exist.

pub fn get<R>(&self) -> Option<&R>
where R: LocalResource + 'static,

Retrieves an immutable reference to a resource of type R.

Returns Some(&R) if the resource exists, otherwise returns None.

pub fn get_mut<R>(&mut self) -> Option<&mut R>
where R: LocalResource + 'static,

Retrieves a mutable reference to a resource of type R.

Returns Some(&mut R) if the resource exists, otherwise returns None.

pub fn remove<R>(&mut self) -> Option<R>
where R: LocalResource,

Removes a resource of type R from the storage.

Returns Some(R) if the resource was present, otherwise None.

Panics

Panics if the resource stored is not of the expected type R. Should be very unlikely.

pub fn contains<R>(&self) -> bool
where R: LocalResource,

Checks if a resource of type R exists in the storage.